@@ -1,6 +1,6 @@
 /* XMRig
- * Copyright (c) 2018-2021 SChernykh   <https://github.com/SChernykh>
- * Copyright (c) 2016-2021 XMRig       <https://github.com/xmrig>, <support@xmrig.com>
+ * Copyright (c) 2018-2025 SChernykh   <https://github.com/SChernykh>
+ * Copyright (c) 2016-2025 XMRig       <https://github.com/xmrig>, <support@xmrig.com>
  *
  *   This program is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -16,21 +16,16 @@
  *   along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef XMRIG_IDNSBACKEND_H
-#define XMRIG_IDNSBACKEND_H
-
+#pragma once
 
 #include "base/tools/Object.h"
 
 
-#include <memory>
-
-
 namespace xmrig {
 
 
+class DnsConfig;
 class DnsRecords;
-class DnsRequest;
 class IDnsListener;
 class String;
 
@@ -43,12 +38,8 @@ public:
     IDnsBackend()           = default;
     virtual ~IDnsBackend()  = default;
 
-    virtual const DnsRecords &records() const                                                               = 0;
-    virtual std::shared_ptr<DnsRequest> resolve(const String &host, IDnsListener *listener, uint64_t ttl)   = 0;
+    virtual void resolve(const String &host, const std::weak_ptr<IDnsListener> &listener, const DnsConfig &config)  = 0;
 };
 
 
-} /* namespace xmrig */
-
-
-#endif // XMRIG_IDNSBACKEND_H
+} // namespace xmrig
