@@ -1,6 +1,6 @@
 /* XMRig
- * Copyright (c) 2018-2021 SChernykh   <https://github.com/SChernykh>
- * Copyright (c) 2016-2021 XMRig       <https://github.com/xmrig>, <support@xmrig.com>
+ * Copyright (c) 2018-2025 SChernykh   <https://github.com/SChernykh>
+ * Copyright (c) 2016-2025 XMRig       <https://github.com/xmrig>, <support@xmrig.com>
  *
  *   This program is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -16,14 +16,11 @@
  *   along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef XMRIG_DNSRECORD_H
-#define XMRIG_DNSRECORD_H
-
+#pragma once
 
 struct addrinfo;
 struct sockaddr;
 
-
 #include "base/tools/String.h"
 
 
@@ -33,28 +30,15 @@ namespace xmrig {
 class DnsRecord
 {
 public:
-    enum Type : uint32_t {
-        Unknown,
-        A,
-        AAAA
-    };
-
     DnsRecord() {}
     DnsRecord(const addrinfo *addr);
 
     const sockaddr *addr(uint16_t port = 0) const;
     String ip() const;
 
-    inline bool isValid() const     { return m_type != Unknown; }
-    inline Type type() const        { return m_type; }
-
 private:
     mutable uint8_t m_data[28]{};
-    const Type m_type = Unknown;
 };
 
 
-} /* namespace xmrig */
-
-
-#endif /* XMRIG_DNSRECORD_H */
+} // namespace xmrig
