@@ -173,7 +173,7 @@ public:
         Value total(kArrayType);
         Value threads(kArrayType);
 
-        double t[3] = { 0.0 };
+        std::pair<bool, double> t[3] = { { true, 0.0 }, { true, 0.0 }, { true, 0.0 } };
 
         for (IBackend *backend : backends) {
             const Hashrate *hr = backend->hashrate();
@@ -181,9 +181,13 @@ public:
                 continue;
             }
 
-            t[0] += hr->calc(Hashrate::ShortInterval);
-            t[1] += hr->calc(Hashrate::MediumInterval);
-            t[2] += hr->calc(Hashrate::LargeInterval);
+            const auto h0 = hr->calc(Hashrate::ShortInterval);
+            const auto h1 = hr->calc(Hashrate::MediumInterval);
+            const auto h2 = hr->calc(Hashrate::LargeInterval);
+
+            if (h0.first) { t[0].second += h0.second; } else { t[0].first = false; }
+            if (h1.first) { t[1].second += h1.second; } else { t[1].first = false; }
+            if (h2.first) { t[2].second += h2.second; } else { t[2].first = false; }
 
             if (version > 1) {
                 continue;
@@ -204,7 +208,7 @@ public:
         total.PushBack(Hashrate::normalize(t[2]),  allocator);
 
         hashrate.AddMember("total",   total, allocator);
-        hashrate.AddMember("highest", Hashrate::normalize(maxHashrate[algorithm]), allocator);
+        hashrate.AddMember("highest", Hashrate::normalize({ maxHashrate[algorithm] > 0.0, maxHashrate[algorithm] }), allocator);
 
         if (version == 1) {
             hashrate.AddMember("threads", threads, allocator);
@@ -283,7 +287,7 @@ public:
     void printHashrate(bool details)
     {
         char num[16 * 5] = { 0 };
-        double speed[3]  = { 0.0 };
+        std::pair<bool, double> speed[3] = { { true, 0.0 }, { true, 0.0 }, { true, 0.0 } };
         uint32_t count   = 0;
 
         double avg_hashrate = 0.0;
@@ -293,9 +297,13 @@ public:
             if (hashrate) {
                 ++count;
 
-                speed[0] += hashrate->calc(Hashrate::ShortInterval);
-                speed[1] += hashrate->calc(Hashrate::MediumInterval);
-                speed[2] += hashrate->calc(Hashrate::LargeInterval);
+                const auto h0 = hashrate->calc(Hashrate::ShortInterval);
+                const auto h1 = hashrate->calc(Hashrate::MediumInterval);
+                const auto h2 = hashrate->calc(Hashrate::LargeInterval);
+
+                if (h0.first) { speed[0].second += h0.second; } else { speed[0].first = false; }
+                if (h1.first) { speed[1].second += h1.second; } else { speed[1].first = false; }
+                if (h2.first) { speed[2].second += h2.second; } else { speed[2].first = false; }
 
                 avg_hashrate += hashrate->average();
             }
@@ -312,8 +320,13 @@ public:
         double scale  = 1.0;
         const char* h = "H/s";
 
-        if ((speed[0] >= 1e6) || (speed[1] >= 1e6) || (speed[2] >= 1e6) || (maxHashrate[algorithm] >= 1e6)) {
+        if ((speed[0].second >= 1e6) || (speed[1].second >= 1e6) || (speed[2].second >= 1e6) || (maxHashrate[algorithm] >= 1e6)) {
             scale = 1e-6;
+
+            speed[0].second *= scale;
+            speed[1].second *= scale;
+            speed[2].second *= scale;
+
             h = "MH/s";
         }
 
@@ -322,16 +335,16 @@ public:
 
 #       ifdef XMRIG_ALGO_GHOSTRIDER
         if (algorithm.family() == Algorithm::GHOSTRIDER) {
-            snprintf(avg_hashrate_buf, sizeof(avg_hashrate_buf), " avg " CYAN_BOLD("%s %s"), Hashrate::format(avg_hashrate * scale, num + 16 * 4, 16), h);
+            snprintf(avg_hashrate_buf, sizeof(avg_hashrate_buf), " avg " CYAN_BOLD("%s %s"), Hashrate::format({ true, avg_hashrate * scale }, num + 16 * 4, 16), h);
         }
 #       endif
 
         LOG_INFO("%s " WHITE_BOLD("speed") " 10s/60s/15m " CYAN_BOLD("%s") CYAN(" %s %s ") CYAN_BOLD("%s") " max " CYAN_BOLD("%s %s") "%s",
                  Tags::miner(),
-                 Hashrate::format(speed[0] * scale,                 num,          16),
-                 Hashrate::format(speed[1] * scale,                 num + 16,     16),
-                 Hashrate::format(speed[2] * scale,                 num + 16 * 2, 16), h,
-                 Hashrate::format(maxHashrate[algorithm] * scale,   num + 16 * 3, 16), h,
+                 Hashrate::format(speed[0],                 num,          16),
+                 Hashrate::format(speed[1],                 num + 16,     16),
+                 Hashrate::format(speed[2],                 num + 16 * 2, 16), h,
+                 Hashrate::format({ maxHashrate[algorithm] > 0.0, maxHashrate[algorithm] * scale },   num + 16 * 3, 16), h,
                  avg_hashrate_buf
                  );
 
@@ -576,6 +589,11 @@ void xmrig::Miner::setJob(const Job &job, bool donate)
 
 #   ifdef XMRIG_ALGO_RANDOMX
     const bool ready = d_ptr->initRX();
+
+    // Always reset nonce on RandomX dataset change
+    if (!ready) {
+        d_ptr->reset = true;
+    }
 #   else
     constexpr const bool ready = true;
 #   endif
@@ -641,7 +659,10 @@ void xmrig::Miner::onTimer(const Timer *)
         }
 
         if (backend->hashrate()) {
-            maxHashrate += backend->hashrate()->calc(Hashrate::ShortInterval);
+            const auto h = backend->hashrate()->calc(Hashrate::ShortInterval);
+            if (h.first) {
+                maxHashrate += h.second;
+            }
         }
     }
 
